GooglePositionerExt

Trait GooglePositionerExt 

pub trait GooglePositionerExt: Send + Sync {
    // Required method
    fn locate<'life0, 'async_trait>(
        &'life0 self,
        options: GooglePositioningOptions,
    ) -> Pin<Box<dyn Future<Output = EveryMapResult<GoogleGeolocationResponse>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Extension trait for Google-specific positioning capabilities.

Provides access to the rich Google Geolocation API response type, which includes more detail than the core PositioningResponse.

use everymap_providers_google::GooglePositionerExt;
let result = positioner.locate(google_options).await?;

Required Methods

fn locate<'life0, 'async_trait>( &'life0 self, options: GooglePositioningOptions, ) -> Pin<Box<dyn Future<Output = EveryMapResult<GoogleGeolocationResponse>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Get a position estimate with rich Google response type. POST /geolocation/v1/geolocate

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors